@@ -33,6 +33,7 @@ impl InMemoryCache {
         self.cache_user(Cow::Owned(member.user), Some(guild_id));
         let cached = CachedMember {
             avatar: member.avatar,
+            communication_disabled_until: member.communication_disabled_until,
             deaf: Some(member.deaf),
             guild_id,
             joined_at: member.joined_at,
@@ -71,6 +72,7 @@ impl InMemoryCache {
 
         let cached = CachedMember {
             avatar: member.avatar.to_owned(),
+            communication_disabled_until: member.communication_disabled_until.to_owned(),
             deaf: Some(member.deaf),
             guild_id,
             joined_at: member.joined_at,
@@ -105,6 +107,7 @@ impl InMemoryCache {
 
         let cached = CachedMember {
             avatar,
+            communication_disabled_until: member.communication_disabled_until.to_owned(),
             deaf,
             guild_id,
             joined_at: member.joined_at,
