@@ -5,11 +5,12 @@ mod guild;
 mod member;
 mod message;
 mod presence;
+mod sticker;
 mod voice_state;
 
 pub use self::{
     emoji::CachedEmoji, guild::CachedGuild, member::CachedMember, message::CachedMessage,
-    presence::CachedPresence, voice_state::CachedVoiceState,
+    presence::CachedPresence, sticker::CachedSticker, voice_state::CachedVoiceState,
 };
 
 #[cfg(tests)]
